@@ -25,7 +25,6 @@ class GrokPattern(object):
         self.pattern = pattern
         self.regex = re.compile(GrokPattern._grok2regex(pattern))
 
-
     def __getattr__(self, attr):
         if attr in dir(self.regex):
             return self.regex.__getattribute__(attr)
@@ -40,7 +39,7 @@ class GrokPattern(object):
             matches = re.findall(r"%{(\w+)(:(\w+)(:(\w+))?)?}", res)
             if len(matches) == 0:
                 return res
-            for match in matches:
+            for match in reversed(matches):
                 name, var_name, typing = match[0], match[2], match[4]
                 if not (name in self.patterns):
                     raise ValueError (f"Pattern not found in templates: {name}.")
@@ -52,8 +51,7 @@ class GrokPattern(object):
                         subs = f"(?P<{var_name}>{self.patterns[name]})"
                     else:
                         subs = f"({self.patterns[name]})"
-
-                res = re.sub(r"%{[^}]+}", subs, res)
+                res = re.sub(r"%{(\w+)(:(\w+)(:(\w+))?)?}", subs, res)
 
 
     @classmethod
@@ -69,7 +67,7 @@ class GrokPattern(object):
         """
         Load all Grok patterns in the file
         """
-        with open(filename, "r") as f:
+        with open(filename, "r", encoding="utf8") as f:
             for line in f:
                 line = re.sub(r"#.*", "", line)
                 line = line.strip()
